# gostep
Serverless Templates Provider for Google cloud platform.

### Prerequisites

* [python v3.x](https://www.python.org/downloads/)
* [Subversion CLI](https://subversion.apache.org/packages.html)
* [gcloud SDK](https://cloud.google.com/sdk)


### How to install

#### From PyPI
```bash
pip install gostep
```

#### From source
Simply clone the repository or download source.
```bash
cd gostep
python setup install
```
